PhoenixFooter class
Phoenix footer. https://github.com/Yalantis/Phoenix
- Inheritance
-
- Object
- Indicator
- Footer
- PhoenixFooter
Constructors
-
const
Properties
- clamping → bool
-
Hold to keep the Scrollable from going out of bounds.
finalinherited
- frictionFactor → FrictionFactor?
-
Friction factor when list is out of bounds.
See BouncingScrollPhysics.frictionFactor.
finalinherited
- hapticFeedback → bool
-
Whether to enable haptic feedback.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hitOver → bool
-
Hit boundary over.
When the Scrollable scrolls by itself, is it out of bounds.
When
clampingis false, it takes effect.finalinherited - horizontalFrictionFactor → FrictionFactor?
-
Horizontal friction factor when list is out of bounds.
See BouncingScrollPhysics.frictionFactor.
finalinherited
- horizontalReadySpringBuilder → SpringBuilder?
-
Horizontal spring effect when the mode is
IndicatorMode.ready.finalinherited - horizontalSpring → SpringDescription?
-
Horizontal spring effect when scrollable goes back.
finalinherited
- infiniteHitOver → bool
-
Infinite scroll hits out of bounds.
When the Scrollable scrolls by itself,
whether the infinite scroll is out of bounds.
When
clampingis false, it takes effect.finalinherited - infiniteOffset → double?
-
Infinite scroll trigger offset.
The relative offset of the Scrollable from the bounds (>= 0)
When null, no infinite scroll.
finalinherited
- key → Key?
-
final
- listenable → IndicatorStateListenable?
-
Indicator state listenable.
Monitor state changes in real time.
finalinherited
- maxOverOffset → double
-
Maximum overscroll offset, will no longer scroll.
When double.infinity, no limit.
finalinherited
- notifyWhenInvisible → bool
-
Notify when invisible.
When
IndicatorNotifier.offset< 0, scrolling will also trigger notification. This might have extra performance overhead, but it's very useful when you need it.finalinherited - position → IndicatorPosition
-
The position of the indicator.
finalinherited
- processedDuration → Duration
-
Task completion delay.
IndicatorMode.processedduration of state.finalinherited - readySpringBuilder → SpringBuilder?
-
Spring effect when the mode is
IndicatorMode.ready.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- safeArea → bool
-
Whether to calculate the safe area.
finalinherited
- secondaryCloseTriggerOffset → double
-
Secondary close trigger offset.
finalinherited
- secondaryDimension → double?
-
Dimension of the second floor.
The default value is ScrollMetrics.viewportDimension.
finalinherited
- secondaryTriggerOffset → double?
-
Trigger offset for secondary.
The indicator will expand and fill the scrollview area.
Will not trigger when null.
finalinherited
- secondaryVelocity → double
-
Secondary opening speed.
finalinherited
- skyColor → Color?
-
Sky color.
final
- spring → SpringDescription?
-
Spring effect when scrollable goes back.
finalinherited
- springRebound → bool
-
Whether the spring can rebound.
Only works with
readySpringBuilder.finalinherited - triggerOffset → double
-
The offset of the trigger task.
finalinherited
- triggerWhenReach → bool
-
Trigger immediately when reaching the
triggerOffset.finalinherited - triggerWhenRelease → bool
-
Over
triggerOffset, the release triggers immediately.finalinherited - triggerWhenReleaseNoWait → bool
-
Over
triggerOffset, the release triggers immediately. No need to wait for task execution to complete, generally used for non-asynchronous events or external custom indicators.finalinherited
Methods
-
build(
BuildContext context, IndicatorState state) → Widget -
Build indicator widget.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited