jtech_base
library
Classes
Admin
ObjectBox Admin allows you to explore the database in a regular web browser.
Allow
Allows the navigation to proceed.
BackgroundTransformer
The default Transformer for Dio .
Backlink
An annotation for a ToMany field of an Entity class to create a relation
based on another relation. See Backlink.new .
BaseAPI
BaseCacheManager
Interface of the CacheManager. In general CacheManager can be used
directly.
BaseConfigProvider <T >
BaseDatabase
BaseOptions
A set of base settings for each Dio().
BaseOptions and Options will be merged into one RequestOptions before
sending the requests. See Options.compose .
BaseProvider
BaseRouter
BaseThemeProvider
Bezier circle footer.
https://dribbble.com/shots/1797373-Pull-Down-To-Refresh
Bezier footer.
Bezier header.
Block
Blocks the navigation from proceeding.
Box <T >
A Box instance gives you access to objects of a particular type.
You get Box instances via Store.box() or Box(Store) .
Build footer widget use IndicatorBuilder.
Build header widget use IndicatorBuilder.
CancelToken
Controls cancellation of Dio 's requests.
ChangeNotifierProvider <T extends ChangeNotifier ? >
Listens to a ChangeNotifier , expose it to its descendants and rebuilds
dependents whenever ChangeNotifier.notifyListeners is called.
ChangeNotifierProxyProvider <T , R extends ChangeNotifier ? >
A ChangeNotifierProvider that builds and synchronizes a ChangeNotifier
with external values.
ChangeNotifierProxyProvider0 <R extends ChangeNotifier ? >
A ChangeNotifierProvider that builds and synchronizes a ChangeNotifier
with external values.
ChangeNotifierProxyProvider2 <T , T2 , R extends ChangeNotifier ? >
A ChangeNotifierProvider that builds and synchronizes a ChangeNotifier
with external values.
ChangeNotifierProxyProvider3 <T , T2 , T3 , R extends ChangeNotifier ? >
A ChangeNotifierProvider that builds and synchronizes a ChangeNotifier
with external values.
ChangeNotifierProxyProvider4 <T , T2 , T3 , T4 , R extends ChangeNotifier ? >
A ChangeNotifierProvider that builds and synchronizes a ChangeNotifier
with external values.
ChangeNotifierProxyProvider5 <T , T2 , T3 , T4 , T5 , R extends ChangeNotifier ? >
A ChangeNotifierProvider that builds and synchronizes a ChangeNotifier
with external values.
ChangeNotifierProxyProvider6 <T , T2 , T3 , T4 , T5 , T6 , R extends ChangeNotifier ? >
A ChangeNotifierProvider that builds and synchronizes a ChangeNotifier
with external values.
Classic footer.
Classic header.
Condition <EntityT >
A Query condition base class.
Consumer <T >
Obtains Provider<T> from its ancestors and passes its value to builder .
Consumer2 <A , B >
Obtains Provider<T> from its ancestors and passes its value to builder .
Consumer3 <A , B , C >
Obtains Provider<T> from its ancestors and passes its value to builder .
Consumer4 <A , B , C , D >
Obtains Provider<T> from its ancestors and passes its value to builder .
Consumer5 <A , B , C , D , E >
Obtains Provider<T> from its ancestors and passes its value to builder .
Consumer6 <A , B , C , D , E , F >
Obtains Provider<T> from its ancestors and passes its value to builder .
Cupertino header.
https://github.com/THEONE10211024/WaterDropListView
CustomDialog
CustomDialogStyle
CustomDialogThemeData
CustomImage
CustomImageThemeData
CustomParameterCodec
annotation to define a custom parameter decoder/encoder
this is useful when the is encoded/decoded in a non-standard way like base64Url
this must be used as an annotation on a field
CustomRefreshController <T >
CustomRefreshThemeData
CustomRefreshView <T >
CustomTheme
CustomTransitionPage <T >
Page with custom transition functionality.
DatePattern
Debounce
DebugFlags
Passed as debugFlags when calling Store.new to enable debug options.
DeferredInheritedProvider <T , R >
An InheritedProvider where the object listened is not the object
emitted.
Delivery footer.
https://dribbble.com/shots/2753803-Refresh-your-delivery
Delivery footer.
https://dribbble.com/shots/2753803-Refresh-your-delivery
Digest
A message digest as computed by a Hash or HMAC function.
Dio
Dio enables you to make HTTP requests easily.
DioMixin
DurationPattern
Entity
An annotation to mark a class as an ObjectBox Entity. See Entity.new .
ErrorInterceptorHandler
The handler for interceptors to handle error occurred during the request.
ExternalName
An annotation to specify the name of an Entity class or field of an
Entity class in an external system. See ExternalName.new .
ExternalType
An annotation to specify the type of a field in an Entity class in an
external system. See ExternalType.new .
FileTool
FlexSchemeData
Immutable data class that holds name and description string scheme
descriptions, light and dark , FlexSchemeColor definitions.
FormData
A class to create readable "multipart/form-data" streams.
It can be used to submit forms and file uploads to http server.
FusedTransformer
A Transformer that has a fast path for decoding UTF8-encoded JSON.
If the response is utf8-encoded JSON and no custom decoder is specified in the RequestOptions , this transformer
is significantly faster than the default SyncTransformer and the BackgroundTransformer .
This improvement is achieved by using a fused Utf8Decoder and JsonDecoder to decode the response,
which is faster than decoding the utf8-encoded JSON in two separate steps, since
Dart uses a special fast decoder for this case.
See https://github.com/dart-lang/sdk/blob/5b2ea0c7a227d91c691d2ff8cbbeb5f7f86afdb9/sdk/lib/_internal/vm/lib/convert_patch.dart#L40
FutureProvider <T >
Listens to a Future and exposes its result to child and its descendants.
GoRoute
Get started
Configuration
Redirection
Transition animations
Named routes
A route that is displayed visually above the matching parent route using the
Navigator .
GoRouteData
Type-safe routes
A class to represent a GoRoute in
Type-safe routing .
GoRouteInformationParser
Converts between incoming URLs and a RouteMatchList using RouteMatcher.
GoRouteInformationProvider
The RouteInformationProvider created by go_router.
GoRouter
Get started
Upgrading
Configuration
Navigation
Redirection
Web
Deep linking
Named routes
Error handling
State restoration
The route configuration for the app.
GoRouterDelegate
GoRouter implementation of RouterDelegate .
GoRouterState
The route state during routing.
Hash
An interface for cryptographic hash functions.
The headers class for requests and responses.
Hmac
An implementation of keyed-hash method authentication codes .
HnswFlags
Flags as a part of the HnswIndex configuration.
HnswIndex
An annotation to create an HSNW index for a field of an Entity class. See
HnswIndex.new .
HttpClientAdapter
HttpAdapter is a bridge between Dio and HttpClient .
Id
An annotation to mark a field of an Entity class as the ID property.
See Id.new .
IdWithScore
Wraps the ID of a matching object and a score when using Query.findIdsWithScores .
ImperativeRouteMatch
The route match that represent route pushed through GoRouter.push .
Index
An annotation to create an index for a field of an Entity class. See
Index.new .
InheritedContext <T >
A BuildContext associated to an InheritedProvider .
InheritedGoRouter
GoRouter implementation of InheritedWidget.
InheritedProvider <T >
A generic implementation of an InheritedWidget .
Interceptor
Interceptor helps to deal with RequestOptions , Response ,
and DioException during the lifecycle of a request
before it reaches users.
Interceptors
A Queue-Model list for Interceptor s.
InterceptorsWrapper
A helper class to create interceptors in ease.
IOHttpClientAdapter
The default HttpClientAdapter for native platforms.
KeepAliveWrapper
ListenableProvider <T extends Listenable ? >
Listens to a Listenable , expose it to its descendants and rebuilds
dependents whenever the listener emits an event.
ListenableProxyProvider <T , R extends Listenable ? >
A variation of ListenableProvider that builds its value from
values obtained from other providers.
ListenableProxyProvider0 <R extends Listenable ? >
A variation of ListenableProvider that builds its value from
values obtained from other providers.
ListenableProxyProvider2 <T , T2 , R extends Listenable ? >
A variation of ListenableProvider that builds its value from
values obtained from other providers.
ListenableProxyProvider3 <T , T2 , T3 , R extends Listenable ? >
A variation of ListenableProvider that builds its value from
values obtained from other providers.
ListenableProxyProvider4 <T , T2 , T3 , T4 , R extends Listenable ? >
A variation of ListenableProvider that builds its value from
values obtained from other providers.
ListenableProxyProvider5 <T , T2 , T3 , T4 , T5 , R extends Listenable ? >
A variation of ListenableProvider that builds its value from
values obtained from other providers.
ListenableProxyProvider6 <T , T2 , T3 , T4 , T5 , T6 , R extends Listenable ? >
A variation of ListenableProvider that builds its value from
values obtained from other providers.
Listener footer.
Listen to the indicator state and respond anywhere.
Listener header.
Listen to the indicator state and respond anywhere.
ListParam <T >
Indicates a param being used as queries or form data,
and how does it gets formatted.
Loading
LoadingFutureBuilder <T >
LoadingFutureThemeData
LoadingOverlay
LoadingOverlayStyle
LoadingStatusBuilder
LoadingStatusStyle
LoadingStatusThemeData
LoadingThemeData
LoadingView
LocalCache
Log
LogInterceptor
LogInterceptor is used to print logs during network requests.
It should be the last interceptor added,
otherwise modifications by following interceptors will not be logged.
This is because the execution of interceptors is in the order of addition.
Material header.
MultipartFile
An upload content that is a part of MultipartRequest.
This doesn't need to correspond to a physical file.
MultiProvider
A provider that merges multiple providers into a single linear widget tree.
It is used to improve readability and reduce boilerplate code of having to
nest multiple layers of providers.
Notice
NoticeThemeData
Parameters when EasyRefresh.onLoad is null.
Overscroll behavior of ScrollView .
NoTransitionPage <T >
Custom transition page with no transition.
Parameters when EasyRefresh.onRefresh is null.
Overscroll behavior of ScrollView .
ObjectWithScore <T >
Wraps a matching object and a score when using Query.findWithScores .
OBXSyncFlags
Flags to adjust Sync client behavior.
OnEnterResult
The result of an onEnter callback.
OptionItem <T >
Options
The configuration for a single request.
BaseOptions and Options will be merged into one RequestOptions before
sending the requests. See Options.compose .
Order
Groups query order flags.
Override the Footer parameter.
First of all you have to make it clear that this is feasible,
otherwise please don't use it.
Override the Header parameter.
First of all you have to make it clear that this is feasible,
otherwise please don't use it.
PageContext
PageProvider
Phoenix footer.
https://github.com/Yalantis/Phoenix
Phoenix header.
https://github.com/Yalantis/Phoenix
Property
An optional annotation to configure how a field of an Entity class is
stored. See Property.new .
PropertyQuery <T >
Property query base.
Provider <T >
A Provider that manages the lifecycle of the value it provides by
delegating to a pair of Create and Dispose .
ProviderBinding
ProviderPage <T extends PageProvider >
ProviderView <T extends BaseProvider >
ProxyProvider <T , R >
A provider that builds a value based on other providers.
ProxyProvider0 <R >
A provider that builds a value based on other providers.
ProxyProvider2 <T , T2 , R >
A provider that builds a value based on other providers.
ProxyProvider3 <T , T2 , T3 , R >
A provider that builds a value based on other providers.
ProxyProvider4 <T , T2 , T3 , T4 , R >
A provider that builds a value based on other providers.
ProxyProvider5 <T , T2 , T3 , T4 , T5 , R >
A provider that builds a value based on other providers.
ProxyProvider6 <T , T2 , T3 , T4 , T5 , T6 , R >
A provider that builds a value based on other providers.
Query <T >
A repeatable Query returning the latest matching Objects.
QueryBacklinkToMany <Source , Target >
QueryBooleanProperty <EntityT >
QueryBuilder <T >
Query builder allows creating reusable queries.
QueryByteVectorProperty <EntityT >
QueryDateNanoProperty <EntityT >
This wraps QueryIntegerProperty for DateTime properties annotated with
@Property(type: PropertyType.dateNano) or
@Property(type: PropertyType.dateNanoUtc) to avoid having to manually convert
to nanoseconds (DateTime.microsecondsSinceEpoch * 1000) when creating
query conditions.
QueryDateProperty <EntityT >
This wraps QueryIntegerProperty for DateTime properties to avoid
having to manually convert to DateTime.millisecondsSinceEpoch when
creating query conditions.
QueryDoubleProperty <EntityT >
QueryDoubleVectorProperty <EntityT >
For double vectors greater and less queries are supported on elements of
the vector (e.g. "has element greater").
QueryHnswProperty <EntityT >
Provides extra conditions for float vector properties with an HnswIndex .
QueryIntegerProperty <EntityT >
QueryIntegerVectorProperty <EntityT >
For integer vectors (excluding QueryByteVectorProperty ) greater, less and
equal are supported on elements of the vector (e.g. "has element greater").
QueryProperty <EntityT , DartType >
The QueryProperty types allow users to build query conditions on a property.
QueryRelationToMany <Source , Target >
QueryRelationToOne <Source , Target >
QueryStringProperty <EntityT >
QueryStringVectorProperty <EntityT >
QueuedInterceptor
Interceptor in queue.
QueuedInterceptorsWrapper
A helper class to create QueuedInterceptor in ease.
ReassembleHandler
If you need your provider to be notified when 'Hot Reload' occurs,
use this class
RedirectRecord
A record that records the redirection happens during requests,
including status code, request method, and the location.
RelativeGoRouteData
Type-safe routes
A class to represent a relative GoRoute in
Type-safe routing .
RequestFileItem
RequestFormBuilder
RequestInterceptorHandler
The handler for interceptors to handle before the request has been sent.
RequestModel
RequestOptions
The internal request option class that is the eventual result after
BaseOptions and Options are composed.
Response <T >
The Response class contains the payload (could be transformed)
that respond from the request, and other information of the response.
ResponseBody
The response wrapper class for adapters.
ResponseInterceptorHandler
The handler for interceptors to handle after respond.
ResponseModel <T >
RouteBase
The base class for GoRoute and ShellRoute .
RouteBuilder
Builds the top-level Navigator for GoRouter.
RouteConfiguration
The route configuration for GoRouter configured by the app.
RouteData
Baseclass for supporting
Type-safe routing .
RouteInformationState <T >
The data class to be stored in RouteInformation.state to be used by
GoRouteInformationParser .
RouteMatch
An matched result by matching a GoRoute against a location.
RouteMatchBase
The base class for various route matches.
RouteMatchList
The list of RouteMatchBase objects.
RoutingConfig
Configuration
A set of parameters that defines routing in GoRouter.
Secondary builder footer.
Secondary builder header.
Secondary footer.
Combine existing Footer with secondary.
Secondary header.
Combine existing Header with secondary.
Selector <A , S >
An equivalent to Consumer that can filter updates by selecting a limited
amount of values and prevent rebuild if they don't change.
Selector0 <T >
A base class for custom Selector .
Selector2 <A , B , S >
An equivalent to Consumer that can filter updates by selecting a limited
amount of values and prevent rebuild if they don't change.
Selector3 <A , B , C , S >
An equivalent to Consumer that can filter updates by selecting a limited
amount of values and prevent rebuild if they don't change.
Selector4 <A , B , C , D , S >
An equivalent to Consumer that can filter updates by selecting a limited
amount of values and prevent rebuild if they don't change.
Selector5 <A , B , C , D , E , S >
An equivalent to Consumer that can filter updates by selecting a limited
amount of values and prevent rebuild if they don't change.
Selector6 <A , B , C , D , E , F , S >
An equivalent to Consumer that can filter updates by selecting a limited
amount of values and prevent rebuild if they don't change.
ShellRoute
Configuration
A route that displays a UI shell around the matching child route.
ShellRouteBase
Base class for classes that act as shells for sub-routes, such
as ShellRoute and StatefulShellRoute .
ShellRouteContext
Context object used when building the shell and Navigator for a shell route.
ShellRouteData
A class to represent a ShellRoute in
Type-safe routing .
ShellRouteMatch
An matched result by matching a ShellRoute against a location.
SingleChildBuilder
A SingleChildWidget that delegates its implementation to a callback.
SingleChildState <T extends SingleChildStatefulWidget >
A State for SingleChildStatefulWidget .
SingleChildStatefulElement
An Element that uses a SingleChildStatefulWidget as its configuration.
SingleChildStatefulWidget
A StatefulWidget that is compatible with Nested.
SingleChildStatelessElement
An Element that uses a SingleChildStatelessWidget as its configuration.
SingleChildStatelessWidget
A StatelessWidget that implements SingleChildWidget and is therefore
compatible with Nested.
SingleChildWidget
A Widget that takes a single descendant.
StatefulNavigationShell
Widget for managing the state of a StatefulShellRoute .
StatefulNavigationShellState
State for StatefulNavigationShell.
StatefulShellBranch
Representation of a separate branch in a stateful navigation tree, used to
configure StatefulShellRoute .
StatefulShellBranchData
Base class for supporting
StatefulShellRoute
StatefulShellRoute
Configuration
A route that displays a UI shell with separate Navigator s for its
sub-routes.
StatefulShellRouteData
Base class for supporting
StatefulShellRoute
Store
Represents an ObjectBox database and works together with Box to allow
getting and putting.
StreamProvider <T >
Listens to a Stream and exposes its content to child and descendants.
Sync
ObjectBox Sync makes data available and
synchronized across devices, online and offline.
SyncChange
Sync incoming data event.
SyncClient
A Sync client is used to connect to an ObjectBox Sync server.
SyncCredentials
Credentials used to authenticate a sync client against a server.
SyncTransformer
If you want to custom the transformation of request/response data,
you can provide a Transformer by your self, and replace
the transformer by setting the Dio.transformer .
TargetIdProperty
An annotation for a ToOne to change the name of its target ID property.
Throttle
ToMany <EntityT >
A to-many relation of an entity that references multiple objects of a "target" entity EntityT.
Tool
ToOne <EntityT >
A to-one relation of an entity that references one object of a "target" entity EntityT.
Transformer
Transformer allows changes to the request/response data before
it is sent/received to/from the server.
Transient
An annotation to mark a field of an Entity class that should not be
stored. See Transient.new .
TypedGoRoute <T extends GoRouteData >
A superclass for each typed go route descendant
TypedQueryParameter
Annotation to override the URI name for a route parameter.
TypedRelativeGoRoute <T extends RelativeGoRouteData >
A superclass for each typed relative go route descendant
TypedRoute <T extends RouteData >
A superclass for each typed route descendant
TypedShellRoute <T extends ShellRouteData >
A superclass for each typed shell route descendant
TypedStatefulShellBranch <T extends StatefulShellBranchData >
A superclass for each typed shell route descendant
TypedStatefulShellRoute <T extends StatefulShellRouteData >
A superclass for each typed shell route descendant
Unique
An annotation to create a unique index for a field of an Entity class. See
Unique.new .
ValueListenableProvider <T >
Listens to a ValueListenable and exposes its current value.
Version
Wrapper for a semantic version information.
Functions
basename (String path )
→ String
Gets the part of path after the last separator.
defaultDioExceptionReadableStringBuilder (DioException e )
→ String
The default implementation of building a readable string of DioException .
extension (String path , [int level = 1 ])
→ String
Gets the file extension of path: the portion of basename from the last
. to the end (including the . itself).
genDateSign ()
→ String
genID ({int ? seed })
→ String
genMd5 (String data )
→ String
getApplicationCacheDirectory ()
→ Future <Directory >
Path to a directory where the application may place application-specific
cache files.
getApplicationDocumentsDirectory ()
→ Future <Directory >
Path to a directory where the application may place data that is
user-generated, or that cannot otherwise be recreated by your application.
getApplicationSupportDirectory ()
→ Future <Directory >
Path to a directory where the application may place application support
files.
getDownloadsDirectory ()
→ Future <Directory ? >
Path to the directory where downloaded files can be stored.
getExternalCacheDirectories ()
→ Future <List <Directory > ? >
Paths to directories where application specific cache data can be stored
externally.
getExternalStorageDirectories ({StorageDirectory ? type })
→ Future <List <Directory > ? >
Paths to directories where application specific data can be stored
externally.
getExternalStorageDirectory ()
→ Future <Directory ? >
Path to a directory where the application may access top level storage.
getLibraryDirectory ()
→ Future <Directory >
Path to the directory where application can store files that are persistent,
backed up, and not visible to the user, such as sqlite.db.
getTemporaryDirectory ()
→ Future <Directory >
Path to the temporary directory on the device that is not backed up and is
suitable for storing caches of downloaded files.
join (String part1 , [String ? part2 , String ? part3 , String ? part4 , String ? part5 , String ? part6 , String ? part7 , String ? part8 , String ? part9 , String ? part10 , String ? part11 , String ? part12 , String ? part13 , String ? part14 , String ? part15 , String ? part16 ])
→ String
Joins the given path parts into a single path using the current platform's
separator . Example:
joinAll (Iterable <String > parts )
→ String
Joins the given path parts into a single path using the current platform's
separator . Example:
range <T extends num > (T value , T begin , T end )
→ T
split (String path )
→ List <String >
Splits path into its components using the current platform's separator .
Typedefs
ConfigCreator <T >
= T Function(dynamic json )
ConfigSerializer <T >
= dynamic Function(T config )
Create <T >
= T Function(BuildContext context )
A function that creates an object of type T.
CustomRefreshControllerValue <T >
= ({List <T > data , LoadStatus loadStatus } )
CustomRefreshWidgetBuilder <T >
= Widget Function(BuildContext context , List <T > data , LoadStatus status )
DefaultTransformer
= SyncTransformer
DeferredStartListening <T , R >
= VoidCallback Function(InheritedContext <R? > context , void setState (R value ), T controller , R? value )
A callback used to handle the subscription of controller.
DioError
= DioException
DioError describes the exception info when a request failed.
DioErrorType
= DioExceptionType
Deprecated in favor of DioExceptionType and will be removed in future major versions.
DioExceptionReadableStringBuilder
= String Function(DioException e )
The readable string builder's signature of
DioException.readableStringBuilder .
DioMediaType
= MediaType
The type (alias) for specifying the content-type of the MultipartFile.
Dispose <T >
= void Function(BuildContext context , T value )
A function that disposes an object of type T.
ErrorBuilder <T >
= T Function(BuildContext context , Object ? error )
A callback used to build a valid value from an error.
ExitCallback
= FutureOr <bool > Function(BuildContext context , GoRouterState state )
Signature for function used in RouteBase.onExit.
GoExceptionHandler
= void Function(BuildContext context , GoRouterState state , GoRouter router )
The function signature of GoRouter.onException.
GoRouterBuilderWithNav
= Widget Function(BuildContext context , Widget child )
Signature of a go router builder function with navigator.
GoRouterPageBuilder
= Page Function(BuildContext context , GoRouterState state )
The page builder for GoRoute .
GoRouterRedirect
= FutureOr <String ? > Function(BuildContext context , GoRouterState state )
The signature of the redirect callback.
GoRouterWidgetBuilder
= Widget Function(BuildContext context , GoRouterState state )
The widget builder for GoRoute .
The signature that iterates header fields.
InterceptorErrorCallback
= void Function(DioException error , ErrorInterceptorHandler handler )
The signature of Interceptor.onError .
InterceptorSendCallback
= void Function(RequestOptions options , RequestInterceptorHandler handler )
The signature of Interceptor.onRequest .
InterceptorSuccessCallback
= void Function(Response response , ResponseInterceptorHandler handler )
The signature of Interceptor.onResponse .
JsonDecodeCallback
= FutureOr Function(String )
The callback definition for decoding a JSON string.
JsonEncodeCallback
= FutureOr <String > Function(Object )
The callback definition for encoding a JSON object.
Locator
= T Function<T >()
A generic function that can be called to read providers, without having a
reference on BuildContext .
NavigationCallback
= Future <RouteMatchList > Function()
The function signature for navigation callbacks in _OnEnterHandler.
NavigatorBuilder
= Widget Function(GlobalKey <NavigatorState > navigatorKey , ShellRouteMatch match , RouteMatchList matchList , List <NavigatorObserver > ? observers , String ? restorationScopeId )
Signature for functions used to build Navigators
OnEnter
= FutureOr <OnEnterResult > Function(BuildContext context , GoRouterState currentState , GoRouterState nextState , GoRouter goRouter )
The signature for the top-level onEnter callback.
OnEnterThenCallback
= FutureOr <void > Function()
Signature for callbacks invoked after an OnEnterResult is resolved.
ParserExceptionHandler
= RouteMatchList Function(BuildContext context , RouteMatchList routeMatchList )
The function signature of GoRouteInformationParser.onParserException .
PopPageWithRouteMatchCallback
= bool Function(Route route , dynamic result , RouteMatchBase match )
Signature for a function that takes in a route to be popped with
the result and returns a boolean decision on whether the pop
is successful.
ProgressCallback
= void Function(int count , int total )
The type of a progress listening callback when sending or receiving data.
ProviderBuilder <R >
= Widget Function(BuildContext context , R value , Widget child )
ProviderSelector <S , T >
= S Function(BuildContext context , T provider )
ProviderSelector2 <S1 , S2 , T >
= (S1 , S2 ) Function(BuildContext context , T provider )
ProviderSelector3 <S1 , S2 , S3 , T >
= (S1 , S2 , S3 ) Function(BuildContext context , T provider )
ProxyProviderBuilder <T , R >
= R Function(BuildContext context , T value , R? previous )
ProxyProviderBuilder2 <T , T2 , R >
= R Function(BuildContext context , T value , T2 value2 , R? previous )
ProxyProviderBuilder3 <T , T2 , T3 , R >
= R Function(BuildContext context , T value , T2 value2 , T3 value3 , R? previous )
ProxyProviderBuilder4 <T , T2 , T3 , T4 , R >
= R Function(BuildContext context , T value , T2 value2 , T3 value3 , T4 value4 , R? previous )
ProxyProviderBuilder5 <T , T2 , T3 , T4 , T5 , R >
= R Function(BuildContext context , T value , T2 value2 , T3 value3 , T4 value4 , T5 value5 , R? previous )
ProxyProviderBuilder6 <T , T2 , T3 , T4 , T5 , T6 , R >
= R Function(BuildContext context , T value , T2 value2 , T3 value3 , T4 value4 , T5 value5 , T6 value6 , R? previous )
RequestEncoder
= FutureOr <List <int > > Function(String request , RequestOptions options )
The type of a request encoding callback.
ResponseDecoder
= FutureOr <String ? > Function(List <int > responseBytes , RequestOptions options , ResponseBody responseBody )
The type of a response decoding callback.
RouteInfoState
= RouteInformationState
Type alias for route information state with dynamic type parameter.
RouteMatchVisitor
= bool Function(RouteMatchBase )
The function signature for RouteMatchList.visitRouteMatches
SelectorBuilder2 <S1 , S2 , T >
= Widget Function(BuildContext context , S1 value1 , S2 value2 , Widget ? child )
SelectorBuilder3 <S1 , S2 , S3 , T >
= Widget Function(BuildContext context , S1 value1 , S2 value2 , S3 value3 , Widget ? child )
ShellNavigationContainerBuilder
= Widget Function(BuildContext context , StatefulNavigationShell navigationShell , List <Widget > children )
Builder for a custom container for the branch Navigators of a
StatefulShellRoute .
ShellRouteBuilder
= Widget Function(BuildContext context , GoRouterState state , Widget child )
The widget builder for ShellRoute .
ShellRoutePageBuilder
= Page Function(BuildContext context , GoRouterState state , Widget child )
The page builder for ShellRoute .
ShouldRebuild <T >
= bool Function(T previous , T next )
Used by providers to determine whether dependents needs to be updated
when the value exposed changes
StartListening <T >
= VoidCallback Function(InheritedContext <T? > element , T value )
A callback used to start the listening of an object and return a function
that cancels the subscription.
StatefulShellRouteBuilder
= Widget Function(BuildContext context , GoRouterState state , StatefulNavigationShell navigationShell )
The widget builder for StatefulShellRoute .
StatefulShellRoutePageBuilder
= Page Function(BuildContext context , GoRouterState state , StatefulNavigationShell navigationShell )
The page builder for StatefulShellRoute .
UpdateShouldNotify <T >
= bool Function(T previous , T current )
A function that returns true when the update from previous to current
should notify listeners, if any.
ValidateStatus
= bool Function(int ? status )
The type of a response status code validate callback.